@@ -12,6 +12,10 @@
 #include "camera.h"
 #include "lc_previewwidget.h"
 
+#ifdef Q_OS_WIN
+#include <QtPlatformHeaders\QWindowsWindowFunctions>
+#endif
+
 lcApplication* gApplication;
 
 void lcPreferences::LoadDefaults()
@@ -67,6 +71,12 @@ void lcPreferences::LoadDefaults()
 	mPartEdgeContrast = lcGetProfileFloat(LC_PROFILE_PART_EDGE_CONTRAST);
 	mPartColorValueLDIndex = lcGetProfileFloat(LC_PROFILE_PART_COLOR_VALUE_LD_INDEX);
 	mAutomateEdgeColor = lcGetProfileInt(LC_PROFILE_AUTOMATE_EDGE_COLOR);
+	mObjectSelectedColor = lcGetProfileUInt(LC_PROFILE_OBJECT_SELECTED_COLOR);
+	mObjectFocusedColor = lcGetProfileUInt(LC_PROFILE_OBJECT_FOCUSED_COLOR);
+	mCameraColor = lcGetProfileUInt(LC_PROFILE_CAMERA_COLOR);
+	mLightColor = lcGetProfileUInt(LC_PROFILE_LIGHT_COLOR);
+	mControlPointColor = lcGetProfileUInt(LC_PROFILE_CONTROL_POINT_COLOR);
+	mControlPointFocusedColor = lcGetProfileUInt(LC_PROFILE_CONTROL_POINT_FOCUSED_COLOR);
 }
 
 void lcPreferences::SaveDefaults()
@@ -121,6 +131,12 @@ void lcPreferences::SaveDefaults()
 	lcSetProfileFloat(LC_PROFILE_PART_EDGE_CONTRAST, mPartEdgeContrast);
 	lcSetProfileFloat(LC_PROFILE_PART_COLOR_VALUE_LD_INDEX, mPartColorValueLDIndex);
 	lcSetProfileInt(LC_PROFILE_AUTOMATE_EDGE_COLOR, mAutomateEdgeColor);
+	lcSetProfileUInt(LC_PROFILE_OBJECT_SELECTED_COLOR, mObjectSelectedColor);
+	lcSetProfileUInt(LC_PROFILE_OBJECT_FOCUSED_COLOR, mObjectFocusedColor);
+	lcSetProfileUInt(LC_PROFILE_CAMERA_COLOR, mCameraColor);
+	lcSetProfileUInt(LC_PROFILE_LIGHT_COLOR, mLightColor);
+	lcSetProfileUInt(LC_PROFILE_CONTROL_POINT_COLOR, mControlPointColor);
+	lcSetProfileUInt(LC_PROFILE_CONTROL_POINT_FOCUSED_COLOR, mControlPointFocusedColor);
 }
 
 void lcPreferences::SetInterfaceColors(lcColorTheme ColorTheme)
@@ -338,20 +354,6 @@ lcCommandLineOptions lcApplication::ParseCommandLineOptions()
 
 	lcCommandLineOptions Options;
 
-	Options.ParseOK = true;
-	Options.Exit = false;
-	Options.SaveImage = false;
-	Options.SaveWavefront = false;
-	Options.Save3DS = false;
-	Options.SaveCOLLADA = false;
-	Options.SaveHTML = false;
-	Options.SetCameraAngles = false;
-	Options.SetCameraPosition = false;
-	Options.Orthographic = false;
-	Options.SetFoV = false;
-	Options.SetZPlanes = false;
-	Options.SetFadeStepsColor = false;
-	Options.SetHighlightColor = false;
 	Options.FadeSteps = Preferences.mFadeSteps;
 	Options.ImageHighlight = Preferences.mHighlightNewParts;
 	Options.ImageWidth = lcGetProfileInt(LC_PROFILE_IMAGE_WIDTH);
@@ -552,7 +554,7 @@ lcCommandLineOptions lcApplication::ParseCommandLineOptions()
 			QString LibPath;
 
 			if (ParseString(LibPath, true))
-				Options.LibraryPaths += qMakePair<QString, bool>(LibPath, false);
+				Options.LibraryPaths += QPair<QString, bool>(LibPath, false);
 		}
 		else if (Option == QLatin1String("-i") || Option == QLatin1String("--image"))
 		{
@@ -772,6 +774,11 @@ lcCommandLineOptions lcApplication::ParseCommandLineOptions()
 			Options.SaveCOLLADA = true;
 			ParseString(Options.SaveCOLLADAName, false);
 		}
+		else if (Option == QLatin1String("-csv") || Option == QLatin1String("--export-csv"))
+		{
+			Options.SaveCSV = true;
+			ParseString(Options.SaveCSVName, false);
+		}
 		else if (Option == QLatin1String("-html") || Option == QLatin1String("--export-html"))
 		{
 			Options.SaveHTML = true;
@@ -814,7 +821,7 @@ lcCommandLineOptions lcApplication::ParseCommandLineOptions()
 			Options.StdOut += tr("  --no-highlight: Do not highlight parts in the steps they appear.\n");
 			Options.StdOut += tr("  --highlight-color: Renderinng color for highlighted parts (#AARRGGBB).\n");
 			Options.StdOut += tr("  --shading <wireframe|flat|default|full>: Select shading mode for rendering.\n");
-			Options.StdOut += tr("  --line-width <width>: Set the with of the edge lines.\n");
+			Options.StdOut += tr("  --line-width <width>: Set the width of the edge lines.\n");
 			Options.StdOut += tr("  --aa-samples <count>: AntiAliasing sample size (1, 2, 4, or 8).\n");
 			Options.StdOut += tr("  -scc, --stud-cylinder-color <#AARRGGBB>: High contrast stud cylinder color.\n");
 			Options.StdOut += tr("  -ec, --edge-color <#AARRGGBB>: High contrast edge color.\n");
@@ -826,6 +833,7 @@ lcCommandLineOptions lcApplication::ParseCommandLineOptions()
 			Options.StdOut += tr("  -obj, --export-wavefront <outfile.obj>: Export the model to Wavefront OBJ format.\n");
 			Options.StdOut += tr("  -3ds, --export-3ds <outfile.3ds>: Export the model to 3D Studio 3DS format.\n");
 			Options.StdOut += tr("  -dae, --export-collada <outfile.dae>: Export the model to COLLADA DAE format.\n");
+			Options.StdOut += tr("  -csv, --export-csv <outfile.csv>: Export the list of parts used in csv format.\n");
 			Options.StdOut += tr("  -html, --export-html <folder>: Create an HTML page for the model.\n");
 			Options.StdOut += tr("  -v, --version: Output version information and exit.\n");
 			Options.StdOut += tr("  -?, --help: Display this help message and exit.\n");
@@ -872,7 +880,7 @@ lcCommandLineOptions lcApplication::ParseCommandLineOptions()
 			Options.StdErr += tr("--camera-position is ignored when --camera-angles is set.\n");
 	}
 
-	const bool SaveAndExit = (Options.SaveImage || Options.SaveWavefront || Options.Save3DS || Options.SaveCOLLADA || Options.SaveHTML);
+	const bool SaveAndExit = (Options.SaveImage || Options.SaveWavefront || Options.Save3DS || Options.SaveCOLLADA || Options.SaveCSV || Options.SaveHTML);
 
 	if (SaveAndExit && Options.ProjectName.isEmpty())
 	{
@@ -913,7 +921,7 @@ lcStartupMode lcApplication::Initialize(const QList<QPair<QString, bool>>& Libra
 		return lcStartupMode::Error;
 	}
 
-	const bool SaveAndExit = (Options.SaveImage || Options.SaveWavefront || Options.Save3DS || Options.SaveCOLLADA || Options.SaveHTML);
+	const bool SaveAndExit = (Options.SaveImage || Options.SaveWavefront || Options.Save3DS || Options.SaveCOLLADA || Options.SaveCSV || Options.SaveHTML);
 
 	if (!SaveAndExit)
 	{
@@ -1175,6 +1183,31 @@ lcStartupMode lcApplication::Initialize(const QList<QPair<QString, bool>>& Libra
 				StdOut << tr("Saved '%1'.\n").arg(FileName);
 		}
 
+		if (Options.SaveCSV)
+		{
+			QString FileName;
+
+			if (!Options.SaveCSVName.isEmpty())
+				FileName = Options.SaveCSVName;
+			else
+				FileName = Options.ProjectName;
+
+			QString Extension = QFileInfo(FileName).suffix().toLower();
+
+			if (Extension.isEmpty())
+			{
+				FileName += ".csv";
+			}
+			else if (Extension != "csv")
+			{
+				FileName = FileName.left(FileName.length() - Extension.length() - 1);
+				FileName += ".csv";
+			}
+
+			if (mProject->ExportCSV(FileName))
+				StdOut << tr("Saved '%1'.\n").arg(FileName);
+		}
+
 		if (Options.SaveHTML)
 		{
 			lcHTMLExportOptions HTMLOptions(mProject);
@@ -1192,6 +1225,10 @@ lcStartupMode lcApplication::Initialize(const QList<QPair<QString, bool>>& Libra
 		gMainWindow->GetPartSelectionWidget()->SetDefaultPart();
 		gMainWindow->UpdateRecentFiles();
 		gMainWindow->show();
+
+#ifdef Q_OS_WIN
+		QWindowsWindowFunctions::setHasBorderInFullScreen(gMainWindow->windowHandle(), true);
+#endif
 	}
 
 	return SaveAndExit ? lcStartupMode::Success : lcStartupMode::ShowWindow;
