@@ -77,6 +77,13 @@ public:
 	bool mAutoLoadMostRecent;
 	bool mRestoreTabLayout;
 	lcColorTheme mColorTheme;
+	quint32 mObjectSelectedColor;
+	quint32 mObjectFocusedColor;
+	quint32 mCameraColor;
+	quint32 mLightColor;
+	quint32 mControlPointColor;
+	quint32 mControlPointFocusedColor;
+
 
 	int mPreviewViewSphereEnabled;
 	int mPreviewViewSphereSize;
@@ -94,23 +101,24 @@ public:
 
 struct lcCommandLineOptions
 {
-	bool ParseOK;
-	bool Exit;
-	bool SaveImage;
-	bool SaveWavefront;
-	bool Save3DS;
-	bool SaveCOLLADA;
-	bool SaveHTML;
-	bool SetCameraAngles;
-	bool SetCameraPosition;
-	bool Orthographic;
-	bool SetFoV;
-	bool SetZPlanes;
-	bool SetFadeStepsColor;
-	bool SetHighlightColor;
-	bool FadeSteps;
-	bool ImageHighlight;
-	bool AutomateEdgeColor;
+	bool ParseOK = true;
+	bool Exit = false;
+	bool SaveImage = false;
+	bool SaveWavefront = false;
+	bool Save3DS = false;
+	bool SaveCOLLADA = false;
+	bool SaveCSV = false;
+	bool SaveHTML = false;
+	bool SetCameraAngles = false;
+	bool SetCameraPosition = false;
+	bool Orthographic = false;
+	bool SetFoV = false;
+	bool SetZPlanes = false;
+	bool SetFadeStepsColor = false;
+	bool SetHighlightColor = false;
+	bool FadeSteps = false;
+	bool ImageHighlight = false;
+	bool AutomateEdgeColor = false;
 	int ImageWidth;
 	int ImageHeight;
 	int AASamples;
@@ -139,6 +147,7 @@ struct lcCommandLineOptions
 	QString SaveWavefrontName;
 	QString Save3DSName;
 	QString SaveCOLLADAName;
+	QString SaveCSVName;
 	QString SaveHTMLName;
 	QList<QPair<QString, bool>> LibraryPaths;
 	QString StdOut;
@@ -160,6 +169,11 @@ public:
 	lcApplication(int& Argc, char** Argv);
 	~lcApplication();
 
+	lcApplication(const lcApplication&) = delete;
+	lcApplication(lcApplication&&) = delete;
+	lcApplication& operator=(const lcApplication&) = delete;
+	lcApplication& operator=(lcApplication&&) = delete;
+
 	void SetProject(Project* Project);
 	static lcCommandLineOptions ParseCommandLineOptions();
 	lcStartupMode Initialize(const QList<QPair<QString, bool>>& LibraryPaths);
