@@ -4,12 +4,14 @@
 #ifdef __cplusplus
 
 #include <QtGlobal>
-#include <QWidget>
-#include <QtOpenGL>
-#include <QGLWidget>
-#include <QtGui>
-#include <QPrinter>
+#include <QtWidgets>
 #include <QtConcurrent>
+#include <QtOpenGL>
+#include <QtGui>
+#include <QWidget>
+#include <QOpenGLWidget>
+#include <QPrinter>
+#include <QPrintDialog>
 #include <map>
 #include <vector>
 #include <array>
@@ -21,6 +23,7 @@
 #pragma warning(default : 4062) // enumerator 'identifier' in switch of enum 'enumeration' is not handled
 #pragma warning(default : 4388) // 'token' : signed/unsigned mismatch
 #pragma warning(default : 4389) // 'equality-operator' : signed/unsigned mismatch
+#pragma warning(default : 5038) // data member 'A::y' will be initialized after data member 'A::x'
 #endif
 
 #ifndef Q_FALLTHROUGH
@@ -36,8 +39,14 @@
 #define LC_ARRAY_SIZE_CHECK(a,s) static_assert(LC_ARRAY_COUNT(a) == static_cast<int>(s), QT_STRINGIFY(a) " size mismatch.")
 
 #if !defined(EGL_VERSION_1_0) && !defined(GL_ES_VERSION_2_0) && !defined(GL_ES_VERSION_3_0) && !defined(QT_OPENGL_ES)
+#ifdef Q_OS_MACOS
+#define LC_FIXED_FUNCTION 0
+#else
+#define LC_FIXED_FUNCTION 1
+#endif
 #else
 #define LC_OPENGLES 1
+#define LC_FIXED_FUNCTION 0
 #endif
 
 // Old defines and declarations.
@@ -54,10 +63,10 @@ char* strupr(char* string);
 #endif
 
 // Version number.
-#define LC_VERSION_MAJOR 21
-#define LC_VERSION_MINOR 06
+#define LC_VERSION_MAJOR 23
+#define LC_VERSION_MINOR 03
 #define LC_VERSION_PATCH 0
-#define LC_VERSION_TEXT "21.06"
+#define LC_VERSION_TEXT "23.03"
 
 // Forward declarations.
 class Project;
@@ -95,10 +104,14 @@ class lcMesh;
 struct lcMeshSection;
 struct lcRenderMesh;
 struct lcObjectSection;
+struct lcPieceInfoRayTest;
 class lcTexture;
 class lcScene;
+class lcViewManipulator;
 class lcViewSphere;
 enum class lcRenderMeshState : int;
+enum class lcTrackTool;
+enum class lcTrackButton;
 
 class lcFile;
 class lcMemFile;
