@@ -23,7 +23,7 @@ enum class lcStudStyle
 	Count
 };
 
-inline bool lcIsHighContrast(lcStudStyle StudStyle)
+constexpr bool lcIsHighContrast(lcStudStyle StudStyle)
 {
 	return StudStyle == lcStudStyle::HighContrast || StudStyle == lcStudStyle::HighContrastLogo;
 }
@@ -98,12 +98,19 @@ enum class lcLibrarySourceType
 
 struct lcLibrarySource
 {
+	lcLibrarySource() = default;
+
 	~lcLibrarySource()
 	{
 		for (const auto& PrimitiveIt : Primitives)
 			delete PrimitiveIt.second;
 	}
 
+	lcLibrarySource(const lcLibrarySource&) = delete;
+	lcLibrarySource(lcLibrarySource&&) = delete;
+	lcLibrarySource& operator=(const lcLibrarySource&) = delete;
+	lcLibrarySource& operator=(lcLibrarySource&&) = delete;
+
 	lcLibrarySourceType Type;
 	std::map<std::string, lcLibraryPrimitive*> Primitives;
 };
@@ -117,7 +124,9 @@ public:
 	~lcPiecesLibrary();
 
 	lcPiecesLibrary(const lcPiecesLibrary&) = delete;
+	lcPiecesLibrary(lcPiecesLibrary&&) = delete;
 	lcPiecesLibrary& operator=(const lcPiecesLibrary&) = delete;
+	lcPiecesLibrary& operator=(lcPiecesLibrary&&) = delete;
 
 	bool Load(const QString& LibraryPath, bool ShowProgress);
 	void LoadColors();
@@ -215,7 +224,11 @@ protected:
 
 	std::vector<std::unique_ptr<lcLibrarySource>> mSources;
 
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+	QRecursiveMutex mLoadMutex;
+#else
 	QMutex mLoadMutex;
+#endif
 	QList<QFuture<void>> mLoadFutures;
 	QList<PieceInfo*> mLoadQueue;
 
