@@ -155,6 +155,10 @@ void lcScene::DrawOpaqueMeshes(lcContext* Context, bool DrawLit, int PrimitiveTy
 
 	Context->SetPolygonOffset(lcPolygonOffset::Opaque);
 
+	const lcPreferences& Preferences = lcGetPreferences();
+	const lcVector4 FocusedColor = lcVector4FromColor(Preferences.mObjectFocusedColor);
+	const lcVector4 SelectedColor = lcVector4FromColor(Preferences.mObjectSelectedColor);
+
 	for (const int MeshIndex : mOpaqueMeshes)
 	{
 		const lcRenderMesh& RenderMesh = mRenderMeshes[MeshIndex];
@@ -195,11 +199,11 @@ void lcScene::DrawOpaqueMeshes(lcContext* Context, bool DrawLit, int PrimitiveTy
 					break;
 
 				case lcRenderMeshState::Selected:
-					Context->SetColorIndexTinted(ColorIndex, LC_COLOR_SELECTED, 0.5f);
+					Context->SetColorIndexTinted(ColorIndex, SelectedColor, 0.5f);
 					break;
 
 				case lcRenderMeshState::Focused:
-					Context->SetColorIndexTinted(ColorIndex, LC_COLOR_FOCUSED, 0.5f);
+					Context->SetColorIndexTinted(ColorIndex, FocusedColor, 0.5f);
 					break;
 
 				case lcRenderMeshState::Faded:
@@ -231,11 +235,11 @@ void lcScene::DrawOpaqueMeshes(lcContext* Context, bool DrawLit, int PrimitiveTy
 					break;
 
 				case lcRenderMeshState::Selected:
-					Context->SetInterfaceColor(LC_COLOR_SELECTED);
+					Context->SetColor(SelectedColor);
 					break;
 
 				case lcRenderMeshState::Focused:
-					Context->SetInterfaceColor(LC_COLOR_FOCUSED);
+					Context->SetColor(FocusedColor);
 					break;
 
 				case lcRenderMeshState::Highlighted:
@@ -262,23 +266,33 @@ void lcScene::DrawOpaqueMeshes(lcContext* Context, bool DrawLit, int PrimitiveTy
 				}
 			}
 
-			lcTexture* const Texture = Section->Texture;
 			int VertexBufferOffset = Mesh->mVertexCacheOffset != -1 ? Mesh->mVertexCacheOffset : 0;
 			const int IndexBufferOffset = Mesh->mIndexCacheOffset != -1 ? Mesh->mIndexCacheOffset : 0;
 
-			if (!Texture)
+			if (Section->PrimitiveType != LC_MESH_TEXTURED_TRIANGLES)
 			{
 				Context->SetMaterial(FlatMaterial);
 				Context->SetVertexFormat(VertexBufferOffset, 3, 1, 0, 0, DrawLit);
 			}
 			else
 			{
-				if (Texture->NeedsUpload())
-					Texture->Upload(Context);
-				Context->SetMaterial(TexturedMaterial);
+				lcTexture* const Texture = Section->Texture;
+
+				if (Texture)
+				{
+					if (Texture->NeedsUpload())
+						Texture->Upload(Context);
+
+					Context->SetMaterial(TexturedMaterial);
+					Context->BindTexture2D(Texture);
+				}
+				else
+				{
+					Context->SetMaterial(FlatMaterial);
+				}
+
 				VertexBufferOffset += Mesh->mNumVertices * sizeof(lcVertex);
 				Context->SetVertexFormat(VertexBufferOffset, 3, 1, 2, 0, DrawLit);
-				Context->BindTexture2D(Texture->mTexture);
 			}
 
 			const GLenum DrawPrimitiveType = Section->PrimitiveType & (LC_MESH_TRIANGLES | LC_MESH_TEXTURED_TRIANGLES) ? GL_TRIANGLES : GL_LINES;
@@ -290,7 +304,7 @@ void lcScene::DrawOpaqueMeshes(lcContext* Context, bool DrawLit, int PrimitiveTy
 #endif
 	}
 
-	Context->BindTexture2D(0);
+	Context->ClearTexture2D();
 	Context->SetPolygonOffset(lcPolygonOffset::None);
 }
 
@@ -314,14 +328,18 @@ void lcScene::DrawTranslucentMeshes(lcContext* Context, bool DrawLit, bool DrawF
 
 	if (!DrawFadePrepass)
 	{
-		glEnable(GL_BLEND);
+		Context->EnableColorBlend(true);
 		Context->SetDepthWrite(false);
 	}
 	else
-		glColorMask(GL_FALSE, GL_FALSE, GL_FALSE, GL_FALSE);
+		Context->EnableColorWrite(false);
 
 	Context->SetPolygonOffset(lcPolygonOffset::Translucent);
 
+	const lcPreferences& Preferences = lcGetPreferences();
+	const lcVector4 FocusedColor = lcVector4FromColor(Preferences.mObjectFocusedColor);
+	const lcVector4 SelectedColor = lcVector4FromColor(Preferences.mObjectSelectedColor);
+
 	for (const lcTranslucentMeshInstance& MeshInstance : mTranslucentMeshes)
 	{
 		const lcRenderMesh& RenderMesh = mRenderMeshes[MeshInstance.RenderMeshIndex];
@@ -354,11 +372,11 @@ void lcScene::DrawTranslucentMeshes(lcContext* Context, bool DrawLit, bool DrawF
 			break;
 
 		case lcRenderMeshState::Selected:
-			Context->SetColorIndexTinted(ColorIndex, LC_COLOR_SELECTED, 0.5f);
+			Context->SetColorIndexTinted(ColorIndex, SelectedColor, 0.5f);
 			break;
 
 		case lcRenderMeshState::Focused:
-			Context->SetColorIndexTinted(ColorIndex, LC_COLOR_FOCUSED, 0.5f);
+			Context->SetColorIndexTinted(ColorIndex, FocusedColor, 0.5f);
 			break;
 
 		case lcRenderMeshState::Faded:
@@ -382,7 +400,7 @@ void lcScene::DrawTranslucentMeshes(lcContext* Context, bool DrawLit, bool DrawF
 			Context->SetMaterial(TexturedMaterial);
 			VertexBufferOffset += Mesh->mNumVertices * sizeof(lcVertex);
 			Context->SetVertexFormat(VertexBufferOffset, 3, 1, 2, 0, DrawLit);
-			Context->BindTexture2D(Texture->mTexture);
+			Context->BindTexture2D(Texture);
 		}
 
 		const GLenum DrawPrimitiveType = Section->PrimitiveType & (LC_MESH_TRIANGLES | LC_MESH_TEXTURED_TRIANGLES) ? GL_TRIANGLES : GL_LINES;
@@ -393,16 +411,16 @@ void lcScene::DrawTranslucentMeshes(lcContext* Context, bool DrawLit, bool DrawF
 #endif
 	}
 
-	Context->BindTexture2D(0);
+	Context->ClearTexture2D();
 	Context->SetPolygonOffset(lcPolygonOffset::None);
 
 	if (!DrawFadePrepass)
 	{
 		Context->SetDepthWrite(true);
-		glDisable(GL_BLEND);
+		Context->EnableColorBlend(false);
 	}
 	else
-		glColorMask(GL_TRUE, GL_TRUE, GL_TRUE, GL_TRUE);
+		Context->EnableColorWrite(true);
 }
 
 void lcScene::Draw(lcContext* Context) const
