@@ -58,7 +58,7 @@ void lcLight::CreateName(const lcArray<lcLight*>& Lights)
 	{
 		bool Found = false;
 
-		for (lcLight* Light : Lights)
+		for (const lcLight* Light : Lights)
 		{
 			if (Light->GetName() == mName)
 			{
@@ -74,14 +74,14 @@ void lcLight::CreateName(const lcArray<lcLight*>& Lights)
 	int MaxLightNumber = 0;
 	const QLatin1String Prefix("Light ");
 
-	for (lcLight* Light : Lights)
+	for (const lcLight* Light : Lights)
 	{
 		QString LightName = Light->GetName();
 
 		if (LightName.startsWith(Prefix))
 		{
 			bool Ok = false;
-			int LightNumber = LightName.midRef(Prefix.size()).toInt(&Ok);
+			int LightNumber = LightName.mid(Prefix.size()).toInt(&Ok);
 
 			if (Ok && LightNumber > MaxLightNumber)
 				MaxLightNumber = LightNumber;
@@ -132,11 +132,14 @@ void lcLight::RayTest(lcObjectRayTest& ObjectRayTest) const
 	lcVector3 End = lcMul31(ObjectRayTest.End, mWorldLight);
 
 	float Distance;
-	if (lcBoundingBoxRayIntersectDistance(Min, Max, Start, End, &Distance, nullptr) && (Distance < ObjectRayTest.Distance))
+	lcVector3 Plane;
+
+	if (lcBoundingBoxRayIntersectDistance(Min, Max, Start, End, &Distance, nullptr, &Plane) && (Distance < ObjectRayTest.Distance))
 	{
 		ObjectRayTest.ObjectSection.Object = const_cast<lcLight*>(this);
 		ObjectRayTest.ObjectSection.Section = LC_LIGHT_SECTION_POSITION;
 		ObjectRayTest.Distance = Distance;
+		ObjectRayTest.PieceInfoRayTest.Plane = Plane;
 	}
 
 	Min = lcVector3(-LC_LIGHT_TARGET_EDGE, -LC_LIGHT_TARGET_EDGE, -LC_LIGHT_TARGET_EDGE);
@@ -148,11 +151,12 @@ void lcLight::RayTest(lcObjectRayTest& ObjectRayTest) const
 	Start = lcMul31(ObjectRayTest.Start, WorldTarget);
 	End = lcMul31(ObjectRayTest.End, WorldTarget);
 
-	if (lcBoundingBoxRayIntersectDistance(Min, Max, Start, End, &Distance, nullptr) && (Distance < ObjectRayTest.Distance))
+	if (lcBoundingBoxRayIntersectDistance(Min, Max, Start, End, &Distance, nullptr, &Plane) && (Distance < ObjectRayTest.Distance))
 	{
 		ObjectRayTest.ObjectSection.Object = const_cast<lcLight*>(this);
 		ObjectRayTest.ObjectSection.Section = LC_LIGHT_SECTION_TARGET;
 		ObjectRayTest.Distance = Distance;
+		ObjectRayTest.PieceInfoRayTest.Plane = Plane;
 	}
 }
 
@@ -175,7 +179,7 @@ void lcLight::BoxTest(lcObjectBoxTest& ObjectBoxTest) const
 
 	for (int PlaneIdx = 0; PlaneIdx < 6; PlaneIdx++)
 	{
-		lcVector3 Normal = lcMul30(ObjectBoxTest.Planes[PlaneIdx], mWorldLight);
+		const lcVector3 Normal = lcMul30(ObjectBoxTest.Planes[PlaneIdx], mWorldLight);
 		LocalPlanes[PlaneIdx] = lcVector4(Normal, ObjectBoxTest.Planes[PlaneIdx][3] - lcDot3(mWorldLight[3], Normal));
 	}
 
@@ -193,7 +197,7 @@ void lcLight::BoxTest(lcObjectBoxTest& ObjectBoxTest) const
 
 	for (int PlaneIdx = 0; PlaneIdx < 6; PlaneIdx++)
 	{
-		lcVector3 Normal = lcMul30(ObjectBoxTest.Planes[PlaneIdx], WorldTarget);
+		const lcVector3 Normal = lcMul30(ObjectBoxTest.Planes[PlaneIdx], WorldTarget);
 		LocalPlanes[PlaneIdx] = lcVector4(Normal, ObjectBoxTest.Planes[PlaneIdx][3] - lcDot3(WorldTarget[3], Normal));
 	}
 
@@ -318,7 +322,7 @@ void lcLight::DrawSpotLight(lcContext* Context) const
 	LightMatrix = lcMatrix44AffineInverse(LightMatrix);
 	LightMatrix.SetTranslation(lcVector3(0, 0, 0));
 
-	lcMatrix44 LightViewMatrix = lcMul(LightMatrix, lcMatrix44Translation(mPosition));
+	const lcMatrix44 LightViewMatrix = lcMul(LightMatrix, lcMatrix44Translation(mPosition));
 	Context->SetWorldMatrix(LightViewMatrix);
 
 	float Verts[(20 + 8 + 2 + 16) * 3];
@@ -375,12 +379,16 @@ void lcLight::DrawSpotLight(lcContext* Context) const
 	Context->SetVertexFormatPosition(3);
 	Context->SetIndexBufferPointer(Indices);
 
-	float LineWidth = lcGetPreferences().mLineWidth;
+	const lcPreferences& Preferences = lcGetPreferences();
+	const float LineWidth = Preferences.mLineWidth;
+	const lcVector4 SelectedColor = lcVector4FromColor(Preferences.mObjectSelectedColor);
+	const lcVector4 FocusedColor = lcVector4FromColor(Preferences.mObjectFocusedColor);
+	const lcVector4 LightColor = lcVector4FromColor(Preferences.mLightColor);
 
 	if (!IsSelected())
 	{
 		Context->SetLineWidth(LineWidth);
-		Context->SetInterfaceColor(LC_COLOR_LIGHT);
+		Context->SetColor(LightColor);
 
 		Context->DrawIndexedPrimitives(GL_LINES, 56 + 24 + 2, GL_UNSIGNED_SHORT, 0);
 	}
@@ -390,14 +398,14 @@ void lcLight::DrawSpotLight(lcContext* Context) const
 		{
 			Context->SetLineWidth(2.0f * LineWidth);
 			if (IsFocused(LC_LIGHT_SECTION_POSITION))
-				Context->SetInterfaceColor(LC_COLOR_FOCUSED);
+				Context->SetColor(FocusedColor);
 			else
-				Context->SetInterfaceColor(LC_COLOR_SELECTED);
+				Context->SetColor(SelectedColor);
 		}
 		else
 		{
 			Context->SetLineWidth(LineWidth);
-			Context->SetInterfaceColor(LC_COLOR_LIGHT);
+			Context->SetColor(LightColor);
 		}
 
 		Context->DrawIndexedPrimitives(GL_LINES, 56, GL_UNSIGNED_SHORT, 0);
@@ -406,20 +414,20 @@ void lcLight::DrawSpotLight(lcContext* Context) const
 		{
 			Context->SetLineWidth(2.0f * LineWidth);
 			if (IsFocused(LC_LIGHT_SECTION_TARGET))
-				Context->SetInterfaceColor(LC_COLOR_FOCUSED);
+				Context->SetColor(FocusedColor);
 			else
-				Context->SetInterfaceColor(LC_COLOR_SELECTED);
+				Context->SetColor(SelectedColor);
 		}
 		else
 		{
 			Context->SetLineWidth(LineWidth);
-			Context->SetInterfaceColor(LC_COLOR_LIGHT);
+			Context->SetColor(LightColor);
 		}
 
 		Context->DrawIndexedPrimitives(GL_LINES, 24, GL_UNSIGNED_SHORT, 56 * 2);
 
 		Context->SetLineWidth(LineWidth);
-		Context->SetInterfaceColor(LC_COLOR_LIGHT);
+		Context->SetColor(LightColor);
 
 		float Radius = tanf(LC_DTOR * mSpotCutoff) * Length;
 
@@ -436,10 +444,10 @@ void lcLight::DrawSpotLight(lcContext* Context) const
 
 void lcLight::DrawPointLight(lcContext* Context) const
 {
-	const int Slices = 6;
-	const int NumIndices = 3 * Slices + 6 * Slices * (Slices - 2) + 3 * Slices;
-	const int NumVertices = (Slices - 1) * Slices + 2;
-	const float Radius = LC_LIGHT_SPHERE_RADIUS;
+	constexpr int Slices = 6;
+	constexpr int NumIndices = 3 * Slices + 6 * Slices * (Slices - 2) + 3 * Slices;
+	constexpr int NumVertices = (Slices - 1) * Slices + 2;
+	constexpr float Radius = LC_LIGHT_SPHERE_RADIUS;
 	lcVector3 Vertices[NumVertices];
 	quint16 Indices[NumIndices];
 
@@ -450,13 +458,13 @@ void lcLight::DrawPointLight(lcContext* Context) const
 
 	for (int i = 1; i < Slices; i++ )
 	{
-		float r0 = Radius * sinf(i * (LC_PI / Slices));
-		float z0 = Radius * cosf(i * (LC_PI / Slices));
+		const float r0 = Radius * sinf(i * (LC_PI / Slices));
+		const float z0 = Radius * cosf(i * (LC_PI / Slices));
 
 		for (int j = 0; j < Slices; j++)
 		{
-			float x0 = r0 * sinf(j * (LC_2PI / Slices));
-			float y0 = r0 * cosf(j * (LC_2PI / Slices));
+			const float x0 = r0 * sinf(j * (LC_2PI / Slices));
+			const float y0 = r0 * cosf(j * (LC_2PI / Slices));
 
 			*Vertex++ = lcVector3(x0, y0, z0);
 		}
@@ -464,7 +472,7 @@ void lcLight::DrawPointLight(lcContext* Context) const
 
 	*Vertex++ = lcVector3(0, 0, -Radius);
 
-	for (int i = 0; i < Slices - 1; i++ )
+	for (quint16 i = 0; i < Slices - 1; i++ )
 	{
 		*Index++ = 0;
 		*Index++ = 1 + i;
@@ -475,12 +483,12 @@ void lcLight::DrawPointLight(lcContext* Context) const
 	*Index++ = 1;
 	*Index++ = 1 + Slices - 1;
 
-	for (int i = 0; i < Slices - 2; i++ )
+	for (quint16 i = 0; i < Slices - 2; i++ )
 	{
-		int Row1 = 1 + i * Slices;
-		int Row2 = 1 + (i + 1) * Slices;
+		quint16 Row1 = 1 + i * Slices;
+		quint16 Row2 = 1 + (i + 1) * Slices;
 
-		for (int j = 0; j < Slices - 1; j++ )
+		for (quint16 j = 0; j < Slices - 1; j++ )
 		{
 			*Index++ = Row1 + j;
 			*Index++ = Row2 + j + 1;
@@ -500,7 +508,7 @@ void lcLight::DrawPointLight(lcContext* Context) const
 		*Index++ = Row1 + 0;
 	}
 
-	for (int i = 0; i < Slices - 1; i++ )
+	for (quint16 i = 0; i < Slices - 1; i++ )
 	{
 		*Index++ = (Slices - 1) * Slices + 1;
 		*Index++ = (Slices - 1) * (Slices - 1) + i;
@@ -513,12 +521,23 @@ void lcLight::DrawPointLight(lcContext* Context) const
 
 	Context->SetWorldMatrix(lcMatrix44Translation(mPosition));
 
+	const lcPreferences& Preferences = lcGetPreferences();
+
 	if (IsFocused(LC_LIGHT_SECTION_POSITION))
-		Context->SetInterfaceColor(LC_COLOR_FOCUSED);
+	{
+		const lcVector4 FocusedColor = lcVector4FromColor(Preferences.mObjectFocusedColor);
+		Context->SetColor(FocusedColor);
+	}
 	else if (IsSelected(LC_LIGHT_SECTION_POSITION))
-		Context->SetInterfaceColor(LC_COLOR_SELECTED);
+	{
+		const lcVector4 SelectedColor = lcVector4FromColor(Preferences.mObjectSelectedColor);
+		Context->SetColor(SelectedColor);
+	}
 	else
-		Context->SetInterfaceColor(LC_COLOR_LIGHT);
+	{
+		const lcVector4 LightColor = lcVector4FromColor(Preferences.mLightColor);
+		Context->SetColor(LightColor);
+	}
 
 	Context->SetVertexBufferPointer(Vertices);
 	Context->SetVertexFormatPosition(3);
