@@ -15,14 +15,14 @@
 #include "lc_qutils.h"
 #include "lc_synth.h"
 
-#define LC_PIECE_CONTROL_POINT_SIZE 10.0f
+constexpr float LC_PIECE_CONTROL_POINT_SIZE = 10.0f;
 
 lcPiece::lcPiece(PieceInfo* Info)
 	: lcObject(lcObjectType::Piece)
 {
 	mMesh = nullptr;
 	SetPieceInfo(Info, QString(), true);
-	mState = 0;
+	mFocusedSection = LC_PIECE_SECTION_INVALID;
 	mColorIndex = gDefaultColor;
 	mColorCode = 16;
 	mStepShow = 1;
@@ -37,7 +37,9 @@ lcPiece::lcPiece(const lcPiece& Other)
 {
 	mMesh = nullptr;
 	SetPieceInfo(Other.mPieceInfo, Other.mID, true);
-	mState = 0;
+	mHidden = Other.mHidden;
+	mSelected = Other.mSelected;
+	mFocusedSection = LC_PIECE_SECTION_INVALID;
 	mColorIndex = Other.mColorIndex;
 	mColorCode = Other.mColorCode;
 	mStepShow = Other.mStepShow;
@@ -46,7 +48,7 @@ lcPiece::lcPiece(const lcPiece& Other)
 	mFileLine = -1;
 
 	mPivotMatrix = Other.mPivotMatrix;
-	mState |= ( Other.mState & LC_PIECE_PIVOT_POINT_VALID );
+	mPivotPointValid = Other.mPivotPointValid;
 
 	mPositionKeys = Other.mPositionKeys;
 	mRotationKeys = Other.mRotationKeys;
@@ -85,7 +87,7 @@ void lcPiece::SetPieceInfo(PieceInfo* Info, const QString& ID, bool Wait)
 	delete mMesh;
 	mMesh = nullptr;
 
-	lcSynthInfo* SynthInfo = mPieceInfo ? mPieceInfo->GetSynthInfo() : nullptr;
+	const lcSynthInfo* SynthInfo = mPieceInfo ? mPieceInfo->GetSynthInfo() : nullptr;
 
 	if (SynthInfo)
 	{
@@ -101,7 +103,7 @@ void lcPiece::UpdateID()
 
 void lcPiece::SaveLDraw(QTextStream& Stream) const
 {
-	QLatin1String LineEnding("\r\n");
+	const QLatin1String LineEnding("\r\n");
 
 	if (mStepHide != LC_STEP_MAX)
 		Stream << QLatin1String("0 !LEOCAD PIECE STEP_HIDE ") << mStepHide << LineEnding;
@@ -109,10 +111,10 @@ void lcPiece::SaveLDraw(QTextStream& Stream) const
 	if (IsHidden())
 		Stream << QLatin1String("0 !LEOCAD PIECE HIDDEN") << LineEnding;
 
-	if (mState & LC_PIECE_PIVOT_POINT_VALID)
+	if (mPivotPointValid)
 	{
 		const float* PivotMatrix = mPivotMatrix;
-		float PivotNumbers[12] = { PivotMatrix[12], -PivotMatrix[14], PivotMatrix[13], PivotMatrix[0], -PivotMatrix[8], PivotMatrix[4], -PivotMatrix[2], PivotMatrix[10], -PivotMatrix[6], PivotMatrix[1], -PivotMatrix[9], PivotMatrix[5] };
+		const float PivotNumbers[12] = { PivotMatrix[12], -PivotMatrix[14], PivotMatrix[13], PivotMatrix[0], -PivotMatrix[8], PivotMatrix[4], -PivotMatrix[2], PivotMatrix[10], -PivotMatrix[6], PivotMatrix[1], -PivotMatrix[9], PivotMatrix[5] };
 
 		Stream << QLatin1String("0 !LEOCAD PIECE PIVOT ");
 
@@ -131,7 +133,7 @@ void lcPiece::SaveLDraw(QTextStream& Stream) const
 	Stream << "1 " << mColorCode << ' ';
 
 	const float* Matrix = mModelWorld;
-	float Numbers[12] = { Matrix[12], -Matrix[14], Matrix[13], Matrix[0], -Matrix[8], Matrix[4], -Matrix[2], Matrix[10], -Matrix[6], Matrix[1], -Matrix[9], Matrix[5] };
+	const float Numbers[12] = { Matrix[12], -Matrix[14], Matrix[13], Matrix[0], -Matrix[8], Matrix[4], -Matrix[2], Matrix[10], -Matrix[6], Matrix[1], -Matrix[9], Matrix[5] };
 
 	for (int NumberIdx = 0; NumberIdx < 12; NumberIdx++)
 		Stream << lcFormatValue(Numbers[NumberIdx], NumberIdx < 3 ? 4 : 6) << ' ';
@@ -156,11 +158,11 @@ bool lcPiece::ParseLDrawLine(QTextStream& Stream)
 			for (int TokenIdx = 0; TokenIdx < 12; TokenIdx++)
 				Stream >> PivotNumbers[TokenIdx];
 
-			lcMatrix44 PivotMatrix(lcVector4( PivotNumbers[3],  PivotNumbers[9], -PivotNumbers[6], 0.0f), lcVector4(PivotNumbers[5], PivotNumbers[11], -PivotNumbers[8], 0.0f),
-								   lcVector4(-PivotNumbers[4], -PivotNumbers[10], PivotNumbers[7], 0.0f), lcVector4(PivotNumbers[0], PivotNumbers[2],  -PivotNumbers[1], 1.0f));
+			const lcMatrix44 PivotMatrix(lcVector4( PivotNumbers[3],  PivotNumbers[9], -PivotNumbers[6], 0.0f), lcVector4(PivotNumbers[5], PivotNumbers[11], -PivotNumbers[8], 0.0f),
+								         lcVector4(-PivotNumbers[4], -PivotNumbers[10], PivotNumbers[7], 0.0f), lcVector4(PivotNumbers[0], PivotNumbers[2],  -PivotNumbers[1], 1.0f));
 
 			mPivotMatrix = PivotMatrix;
-			mState |= LC_PIECE_PIVOT_POINT_VALID;
+			mPivotPointValid = true;
 		}
 		else if (Token == QLatin1String("POSITION_KEY"))
 			mPositionKeys.LoadKeysLDraw(Stream);
@@ -346,7 +348,7 @@ bool lcPiece::FileLoad(lcFile& file)
 			quint8 Hidden;
 			file.ReadU8(&Hidden, 1);
 			if (Hidden & 1)
-				mState |= LC_PIECE_HIDDEN;
+				mHidden = true;
 			file.ReadU8(&ch, 1);
 			file.Seek(ch, SEEK_CUR);
 		}
@@ -355,7 +357,7 @@ bool lcPiece::FileLoad(lcFile& file)
 			qint32 hide;
 			file.ReadS32(&hide, 1);
 			if (hide != 0)
-				mState |= LC_PIECE_HIDDEN;
+				mHidden = true;
 			file.Seek(81, SEEK_CUR);
 		}
 
@@ -375,7 +377,7 @@ bool lcPiece::FileLoad(lcFile& file)
 
 		file.ReadU8(&ch, 1);
 		if (ch & 0x01)
-			mState |= LC_PIECE_HIDDEN;
+			mHidden = true;
 	}
 
 	return true;
@@ -461,42 +463,50 @@ void lcPiece::RemoveTime(lcStep Start, lcStep Time)
 
 void lcPiece::RayTest(lcObjectRayTest& ObjectRayTest) const
 {
-	lcMatrix44 InverseWorldMatrix = lcMatrix44AffineInverse(mModelWorld);
-	lcVector3 Start = lcMul31(ObjectRayTest.Start, InverseWorldMatrix);
-	lcVector3 End = lcMul31(ObjectRayTest.End, InverseWorldMatrix);
+	const lcMatrix44 InverseWorldMatrix = lcMatrix44AffineInverse(mModelWorld);
+	const lcVector3 Start = lcMul31(ObjectRayTest.Start, InverseWorldMatrix);
+	const lcVector3 End = lcMul31(ObjectRayTest.End, InverseWorldMatrix);
 
 	if (mMesh)
 	{
-		if (mMesh->MinIntersectDist(Start, End, ObjectRayTest.Distance))
+		if (mMesh->MinIntersectDist(Start, End, ObjectRayTest.Distance, ObjectRayTest.PieceInfoRayTest.Plane))
 		{
 			ObjectRayTest.ObjectSection.Object = const_cast<lcPiece*>(this);
 			ObjectRayTest.ObjectSection.Section = LC_PIECE_SECTION_POSITION;
+			ObjectRayTest.PieceInfoRayTest.Transform = mModelWorld;
 		}
 	}
-	else if (mPieceInfo->MinIntersectDist(Start, End, ObjectRayTest.Distance))
+	else
 	{
-		ObjectRayTest.ObjectSection.Object = const_cast<lcPiece*>(this);
-		ObjectRayTest.ObjectSection.Section = LC_PIECE_SECTION_POSITION;
+		if (mPieceInfo->MinIntersectDist(Start, End, ObjectRayTest.Distance, ObjectRayTest.PieceInfoRayTest))
+		{
+			ObjectRayTest.ObjectSection.Object = const_cast<lcPiece*>(this);
+			ObjectRayTest.ObjectSection.Section = LC_PIECE_SECTION_POSITION;
+			ObjectRayTest.PieceInfoRayTest.Transform = lcMul(ObjectRayTest.PieceInfoRayTest.Transform, mModelWorld);
+		}
 	}
 
 	if (AreControlPointsVisible())
 	{
-		lcVector3 Min(-LC_PIECE_CONTROL_POINT_SIZE, -LC_PIECE_CONTROL_POINT_SIZE, -LC_PIECE_CONTROL_POINT_SIZE);
-		lcVector3 Max(LC_PIECE_CONTROL_POINT_SIZE, LC_PIECE_CONTROL_POINT_SIZE, LC_PIECE_CONTROL_POINT_SIZE);
+		const lcVector3 Min(-LC_PIECE_CONTROL_POINT_SIZE, -LC_PIECE_CONTROL_POINT_SIZE, -LC_PIECE_CONTROL_POINT_SIZE);
+		const lcVector3 Max(LC_PIECE_CONTROL_POINT_SIZE, LC_PIECE_CONTROL_POINT_SIZE, LC_PIECE_CONTROL_POINT_SIZE);
 
 		for (int ControlPointIdx = 0; ControlPointIdx < mControlPoints.GetSize(); ControlPointIdx++)
 		{
-			lcMatrix44 InverseTransform = lcMatrix44AffineInverse(mControlPoints[ControlPointIdx].Transform);
-			lcVector3 PointStart = lcMul31(Start, InverseTransform);
-			lcVector3 PointEnd = lcMul31(End, InverseTransform);
+			const lcMatrix44 InverseTransform = lcMatrix44AffineInverse(mControlPoints[ControlPointIdx].Transform);
+			const lcVector3 PointStart = lcMul31(Start, InverseTransform);
+			const lcVector3 PointEnd = lcMul31(End, InverseTransform);
 
 			float Distance;
-			if (!lcBoundingBoxRayIntersectDistance(Min, Max, PointStart, PointEnd, &Distance, nullptr) || (Distance >= ObjectRayTest.Distance))
-				continue;
+			lcVector3 Plane;
 
-			ObjectRayTest.ObjectSection.Object = const_cast<lcPiece*>(this);
-			ObjectRayTest.ObjectSection.Section = LC_PIECE_SECTION_CONTROL_POINT_1 + ControlPointIdx;
-			ObjectRayTest.Distance = Distance;
+			if (lcBoundingBoxRayIntersectDistance(Min, Max, PointStart, PointEnd, &Distance, nullptr, &Plane))
+			{
+				ObjectRayTest.ObjectSection.Object = const_cast<lcPiece*>(this);
+				ObjectRayTest.ObjectSection.Section = LC_PIECE_SECTION_CONTROL_POINT_FIRST + ControlPointIdx;
+				ObjectRayTest.Distance = Distance;
+				ObjectRayTest.PieceInfoRayTest.Plane = Plane;
+			}
 		}
 	}
 }
@@ -509,7 +519,9 @@ void lcPiece::BoxTest(lcObjectBoxTest& ObjectBoxTest) const
 
 void lcPiece::DrawInterface(lcContext* Context, const lcScene& Scene) const
 {
-	float LineWidth = lcGetPreferences().mLineWidth;
+	const lcPreferences& Preferences = lcGetPreferences();
+	const float LineWidth = Preferences.mLineWidth;
+
 	Context->SetLineWidth(2.0f * LineWidth);
 
 	const lcBoundingBox& BoundingBox = GetBoundingBox();
@@ -552,14 +564,20 @@ void lcPiece::DrawInterface(lcContext* Context, const lcScene& Scene) const
 		{ Min[0], Min[1], Min[2] }, { Min[0], Min[1], Min[2] + Edge[2] },
 	};
 
-	lcMatrix44 WorldMatrix = Scene.ApplyActiveSubmodelTransform(mModelWorld);
+	const lcMatrix44 WorldMatrix = Scene.ApplyActiveSubmodelTransform(mModelWorld);
 	Context->SetMaterial(lcMaterialType::UnlitColor);
 	Context->SetWorldMatrix(WorldMatrix);
 
 	if (IsFocused(LC_PIECE_SECTION_POSITION))
-		Context->SetInterfaceColor(LC_COLOR_FOCUSED);
+	{
+		const lcVector4 FocusedColor = lcVector4FromColor(Preferences.mObjectFocusedColor);
+		Context->SetColor(FocusedColor);
+	}
 	else
-		Context->SetInterfaceColor(LC_COLOR_SELECTED);
+	{
+		const lcVector4 SelectedColor = lcVector4FromColor(Preferences.mObjectSelectedColor);
+		Context->SetColor(SelectedColor);
+	}
 
 	Context->SetVertexBufferPointer(LineVerts);
 	Context->SetVertexFormatPosition(3);
@@ -568,8 +586,8 @@ void lcPiece::DrawInterface(lcContext* Context, const lcScene& Scene) const
 
 	if (IsPivotPointVisible())
 	{
-		const float Size = 5.0f;
-		const float Verts[8 * 3] =
+		constexpr float Size = 5.0f;
+		constexpr float Verts[8 * 3] =
 		{
 			-Size, -Size, -Size, -Size,  Size, -Size, Size,  Size, -Size, Size, -Size, -Size,
 			-Size, -Size,  Size, -Size,  Size,  Size, Size,  Size,  Size, Size, -Size,  Size
@@ -612,9 +630,12 @@ void lcPiece::DrawInterface(lcContext* Context, const lcScene& Scene) const
 			7, 3, 2, 6, 7, 2, 0, 3, 7, 0, 7, 4, 6, 2, 1, 5, 6, 1
 		};
 
-		glEnable(GL_BLEND);
+		Context->EnableColorBlend(true);
 		Context->EnableCullFace(true);
 
+		const lcVector4 ControlPointColor = lcVector4FromColor(Preferences.mControlPointColor);
+		const lcVector4 ControlPointFocusedColor = lcVector4FromColor(Preferences.mControlPointFocusedColor);
+
 		for (int ControlPointIdx = 0; ControlPointIdx < mControlPoints.GetSize(); ControlPointIdx++)
 		{
 			Context->SetWorldMatrix(lcMul(mControlPoints[ControlPointIdx].Transform, WorldMatrix));
@@ -623,16 +644,16 @@ void lcPiece::DrawInterface(lcContext* Context, const lcScene& Scene) const
 			Context->SetVertexFormatPosition(3);
 			Context->SetIndexBufferPointer(Indices);
 
-			if (IsFocused(LC_PIECE_SECTION_CONTROL_POINT_1 + ControlPointIdx))
-				Context->SetInterfaceColor(LC_COLOR_CONTROL_POINT_FOCUSED);
+			if (IsFocused(LC_PIECE_SECTION_CONTROL_POINT_FIRST + ControlPointIdx))
+				Context->SetColor(ControlPointFocusedColor);
 			else
-				Context->SetInterfaceColor(LC_COLOR_CONTROL_POINT);
+				Context->SetColor(ControlPointColor);
 
 			Context->DrawIndexedPrimitives(GL_TRIANGLES, 36, GL_UNSIGNED_SHORT, 0);
 		}
 
 		Context->EnableCullFace(false);
-		glDisable(GL_BLEND);
+		Context->EnableColorBlend(false);
 	}
 }
 
@@ -658,7 +679,7 @@ void lcPiece::AddMainModelRenderMeshes(lcScene* Scene, bool Highlight, bool Fade
 
 	if (Scene->GetDrawInterface())
 	{
-		lcPiece* ActiveSubmodelInstance = Scene->GetActiveSubmodelInstance();
+		const lcPiece* ActiveSubmodelInstance = Scene->GetActiveSubmodelInstance();
 
 		if (!ActiveSubmodelInstance)
 			RenderMeshState = IsFocused() ? lcRenderMeshState::Focused : (IsSelected() ? lcRenderMeshState::Selected : RenderMeshState);
@@ -684,7 +705,7 @@ void lcPiece::AddSubModelRenderMeshes(lcScene* Scene, const lcMatrix44& WorldMat
 	if (ColorIndex == gDefaultColor)
 		ColorIndex = DefaultColorIndex;
 
-	lcPiece* ActiveSubmodelInstance = Scene->GetActiveSubmodelInstance();
+	const lcPiece* ActiveSubmodelInstance = Scene->GetActiveSubmodelInstance();
 
 	if (ActiveSubmodelInstance == this)
 		RenderMeshState = lcRenderMeshState::Default;
@@ -722,11 +743,11 @@ void lcPiece::SubModelAddBoundingBoxPoints(const lcMatrix44& WorldMatrix, std::v
 
 void lcPiece::MoveSelected(lcStep Step, bool AddKey, const lcVector3& Distance)
 {
-	quint32 Section = GetFocusSection();
+	const quint32 Section = GetFocusSection();
 
 	if (Section == LC_PIECE_SECTION_POSITION || Section == LC_PIECE_SECTION_INVALID)
 	{
-		lcVector3 Position = mModelWorld.GetTranslation() + Distance;
+		const lcVector3 Position = mModelWorld.GetTranslation() + Distance;
 
 		SetPosition(Position, Step, AddKey);
 
@@ -734,11 +755,11 @@ void lcPiece::MoveSelected(lcStep Step, bool AddKey, const lcVector3& Distance)
 	}
 	else
 	{
-		int ControlPointIndex = Section - LC_PIECE_SECTION_CONTROL_POINT_1;
+		const int ControlPointIndex = Section - LC_PIECE_SECTION_CONTROL_POINT_FIRST;
 
 		if (ControlPointIndex >= 0 && ControlPointIndex < mControlPoints.GetSize())
 		{
-			lcMatrix33 InverseWorldMatrix = lcMatrix33AffineInverse(lcMatrix33(mModelWorld));
+			const lcMatrix33 InverseWorldMatrix = lcMatrix33AffineInverse(lcMatrix33(mModelWorld));
 			lcMatrix44& Transform = mControlPoints[ControlPointIndex].Transform;
 
 			Transform.SetTranslation(Transform.GetTranslation() + lcMul(Distance, InverseWorldMatrix));
@@ -750,17 +771,17 @@ void lcPiece::MoveSelected(lcStep Step, bool AddKey, const lcVector3& Distance)
 
 void lcPiece::Rotate(lcStep Step, bool AddKey, const lcMatrix33& RotationMatrix, const lcVector3& Center, const lcMatrix33& RotationFrame)
 {
-	quint32 Section = GetFocusSection();
+	const quint32 Section = GetFocusSection();
 
 	if (Section == LC_PIECE_SECTION_POSITION || Section == LC_PIECE_SECTION_INVALID)
 	{
 		lcVector3 Distance = mModelWorld.GetTranslation() - Center;
-		lcMatrix33 LocalToWorldMatrix = lcMatrix33(mModelWorld);
+		const lcMatrix33 LocalToWorldMatrix = lcMatrix33(mModelWorld);
 
-		lcMatrix33 LocalToFocusMatrix = lcMul(LocalToWorldMatrix, RotationFrame);
+		const lcMatrix33 LocalToFocusMatrix = lcMul(LocalToWorldMatrix, RotationFrame);
 		lcMatrix33 NewLocalToWorldMatrix = lcMul(LocalToFocusMatrix, RotationMatrix);
 
-		lcMatrix33 WorldToLocalMatrix = lcMatrix33AffineInverse(LocalToWorldMatrix);
+		const lcMatrix33 WorldToLocalMatrix = lcMatrix33AffineInverse(LocalToWorldMatrix);
 
 		Distance = lcMul(Distance, WorldToLocalMatrix);
 		Distance = lcMul(Distance, NewLocalToWorldMatrix);
@@ -772,15 +793,15 @@ void lcPiece::Rotate(lcStep Step, bool AddKey, const lcMatrix33& RotationMatrix,
 	}
 	else
 	{
-		int ControlPointIndex = Section - LC_PIECE_SECTION_CONTROL_POINT_1;
+		const int ControlPointIndex = Section - LC_PIECE_SECTION_CONTROL_POINT_FIRST;
 
 		if (ControlPointIndex >= 0 && ControlPointIndex < mControlPoints.GetSize())
 		{
 			lcMatrix44& Transform = mControlPoints[ControlPointIndex].Transform;
-			lcMatrix33 PieceWorldMatrix(mModelWorld);
-			lcMatrix33 LocalToWorldMatrix = lcMul(lcMatrix33(Transform), PieceWorldMatrix);
+			const lcMatrix33 PieceWorldMatrix(mModelWorld);
+			const lcMatrix33 LocalToWorldMatrix = lcMul(lcMatrix33(Transform), PieceWorldMatrix);
 
-			lcMatrix33 LocalToFocusMatrix = lcMul(LocalToWorldMatrix, RotationFrame);
+			const lcMatrix33 LocalToFocusMatrix = lcMul(LocalToWorldMatrix, RotationFrame);
 			lcMatrix33 NewLocalToWorldMatrix = lcMul(lcMul(LocalToFocusMatrix, RotationMatrix), lcMatrix33AffineInverse(PieceWorldMatrix));
 
 			NewLocalToWorldMatrix.Orthonormalize();
@@ -797,7 +818,7 @@ void lcPiece::MovePivotPoint(const lcVector3& Distance)
 		return;
 
 	mPivotMatrix.SetTranslation(mPivotMatrix.GetTranslation() + lcMul30(Distance, lcMatrix44AffineInverse(mModelWorld)));
-	mState |= LC_PIECE_PIVOT_POINT_VALID;
+	mPivotPointValid = true;
 }
 
 void lcPiece::RotatePivotPoint(const lcMatrix33& RotationMatrix)
@@ -809,19 +830,20 @@ void lcPiece::RotatePivotPoint(const lcMatrix33& RotationMatrix)
 	NewPivotRotationMatrix.Orthonormalize();
 
 	mPivotMatrix = lcMatrix44(NewPivotRotationMatrix, mPivotMatrix.GetTranslation());
-	mState |= LC_PIECE_PIVOT_POINT_VALID;
+	mPivotPointValid = true;
 }
 
 quint32 lcPiece::GetAllowedTransforms() const
 {
-	const quint32 Move = LC_OBJECT_TRANSFORM_MOVE_X | LC_OBJECT_TRANSFORM_MOVE_Y | LC_OBJECT_TRANSFORM_MOVE_Z;
-	const quint32 Rotate = LC_OBJECT_TRANSFORM_ROTATE_X | LC_OBJECT_TRANSFORM_ROTATE_Y | LC_OBJECT_TRANSFORM_ROTATE_Z;
-	quint32 Section = GetFocusSection();
+	constexpr quint32 Move = LC_OBJECT_TRANSFORM_MOVE_X | LC_OBJECT_TRANSFORM_MOVE_Y | LC_OBJECT_TRANSFORM_MOVE_Z;
+	constexpr quint32 Rotate = LC_OBJECT_TRANSFORM_ROTATE_X | LC_OBJECT_TRANSFORM_ROTATE_Y | LC_OBJECT_TRANSFORM_ROTATE_Z;
+	const quint32 Section = GetFocusSection();
 
 	if (Section == LC_PIECE_SECTION_POSITION || Section == LC_PIECE_SECTION_INVALID)
 		return Move | Rotate;
 
-	lcSynthInfo* SynthInfo = mPieceInfo->GetSynthInfo();
+	const lcSynthInfo* SynthInfo = mPieceInfo->GetSynthInfo();
+
 	if (SynthInfo)
 	{
 		if (SynthInfo->IsUnidirectional())
@@ -842,13 +864,13 @@ bool lcPiece::CanAddControlPoint() const
 	if (mControlPoints.GetSize() >= LC_MAX_CONTROL_POINTS)
 		return false;
 
-	lcSynthInfo* SynthInfo = mPieceInfo->GetSynthInfo();
+	const lcSynthInfo* SynthInfo = mPieceInfo->GetSynthInfo();
 	return SynthInfo && SynthInfo->CanAddControlPoints();
 }
 
 bool lcPiece::CanRemoveControlPoint() const
 {
-	quint32 Section = GetFocusSection();
+	const quint32 Section = GetFocusSection();
 	return Section >= LC_PIECE_SECTION_CONTROL_POINT_FIRST && Section <= LC_PIECE_SECTION_CONTROL_POINT_LAST && mControlPoints.GetSize() > 2;
 }
 
@@ -857,17 +879,17 @@ bool lcPiece::InsertControlPoint(const lcVector3& WorldStart, const lcVector3& W
 	if (!CanAddControlPoint())
 		return false;
 
-	lcMatrix44 InverseWorldMatrix = lcMatrix44AffineInverse(mModelWorld);
-	lcVector3 Start = lcMul31(WorldStart, InverseWorldMatrix);
-	lcVector3 End = lcMul31(WorldEnd, InverseWorldMatrix);
+	const lcMatrix44 InverseWorldMatrix = lcMatrix44AffineInverse(mModelWorld);
+	const lcVector3 Start = lcMul31(WorldStart, InverseWorldMatrix);
+	const lcVector3 End = lcMul31(WorldEnd, InverseWorldMatrix);
 
-	lcSynthInfo* SynthInfo = mPieceInfo->GetSynthInfo();
-	int ControlPointIndex = SynthInfo->InsertControlPoint(mControlPoints, Start, End);
+	const lcSynthInfo* SynthInfo = mPieceInfo->GetSynthInfo();
+	const int ControlPointIndex = SynthInfo->InsertControlPoint(mControlPoints, Start, End);
 
 	if (ControlPointIndex)
 	{
 		SetFocused(GetFocusSection(), false);
-		SetFocused(LC_PIECE_SECTION_CONTROL_POINT_1 + ControlPointIndex, true);
+		SetFocused(LC_PIECE_SECTION_CONTROL_POINT_FIRST + ControlPointIndex, true);
 		UpdateMesh();
 		return true;
 	}
@@ -877,7 +899,7 @@ bool lcPiece::InsertControlPoint(const lcVector3& WorldStart, const lcVector3& W
 
 bool lcPiece::RemoveFocusedControlPoint()
 {
-	int ControlPointIndex = GetFocusSection() - LC_PIECE_SECTION_CONTROL_POINT_1;
+	const int ControlPointIndex = GetFocusSection() - LC_PIECE_SECTION_CONTROL_POINT_FIRST;
 
 	if (ControlPointIndex < 0 || ControlPointIndex >= mControlPoints.GetSize() || mControlPoints.GetSize() <= 2)
 		return false;
@@ -893,7 +915,8 @@ bool lcPiece::RemoveFocusedControlPoint()
 
 void lcPiece::VerifyControlPoints(lcArray<lcPieceControlPoint>& ControlPoints) const
 {
-	lcSynthInfo* SynthInfo = mPieceInfo->GetSynthInfo();
+	const lcSynthInfo* SynthInfo = mPieceInfo->GetSynthInfo();
+
 	if (!SynthInfo)
 	{
 		ControlPoints.RemoveAll();
@@ -914,15 +937,12 @@ QString lcPiece::GetName() const
 
 bool lcPiece::IsVisible(lcStep Step) const
 {
-	if (mState & LC_PIECE_HIDDEN)
-		return false;
-
-	return (mStepShow <= Step) && (mStepHide > Step || mStepHide == LC_STEP_MAX);
+	return !mHidden && (mStepShow <= Step) && (mStepHide > Step || mStepHide == LC_STEP_MAX);
 }
 
 bool lcPiece::IsVisibleInSubModel() const
 {
-	return (mStepHide == LC_STEP_MAX) && !(mState & LC_PIECE_HIDDEN);
+	return (mStepHide == LC_STEP_MAX) && !mHidden;
 }
 
 void lcPiece::GetModelParts(const lcMatrix44& WorldMatrix, int DefaultColorIndex, std::vector<lcModelPartsEntry>& ModelParts) const
@@ -938,7 +958,7 @@ void lcPiece::GetModelParts(const lcMatrix44& WorldMatrix, int DefaultColorIndex
 	if (!mMesh)
 		mPieceInfo->GetModelParts(lcMul(mModelWorld, WorldMatrix), ColorIndex, ModelParts);
 	else
-		ModelParts.emplace_back(lcModelPartsEntry{ WorldMatrix, mPieceInfo, mMesh, DefaultColorIndex });
+		ModelParts.emplace_back(lcModelPartsEntry{ lcMul(mModelWorld, WorldMatrix), mPieceInfo, mMesh, ColorIndex });
 }
 
 const lcBoundingBox& lcPiece::GetBoundingBox() const
@@ -961,7 +981,7 @@ void lcPiece::CompareBoundingBox(lcVector3& Min, lcVector3& Max) const
 
 		for (int i = 0; i < 8; i++)
 		{
-			lcVector3 Point = lcMul31(Points[i], mModelWorld);
+			const lcVector3 Point = lcMul31(Points[i], mModelWorld);
 
 			Min = lcMin(Point, Min);
 			Max = lcMax(Point, Max);
@@ -976,8 +996,8 @@ lcGroup* lcPiece::GetTopGroup()
 
 void lcPiece::UpdatePosition(lcStep Step)
 {
-	lcVector3 Position = mPositionKeys.CalculateKey(Step);
-	lcMatrix33 Rotation = mRotationKeys.CalculateKey(Step);
+	const lcVector3 Position = mPositionKeys.CalculateKey(Step);
+	const lcMatrix33 Rotation = mRotationKeys.CalculateKey(Step);
 
 	mModelWorld = lcMatrix44(Rotation, Position);
 }
@@ -985,6 +1005,6 @@ void lcPiece::UpdatePosition(lcStep Step)
 void lcPiece::UpdateMesh()
 {
 	delete mMesh;
-	lcSynthInfo* SynthInfo = mPieceInfo->GetSynthInfo();
+	const lcSynthInfo* SynthInfo = mPieceInfo->GetSynthInfo();
 	mMesh = SynthInfo ? SynthInfo->CreateMesh(mControlPoints) : nullptr;
 }
