@@ -517,9 +517,15 @@ QWidget *lcQPropertiesTree::createEditor(QWidget *parent, QTreeWidgetItem *item)
 			lcPiecesLibrary* Library = lcGetPiecesLibrary();
 			std::vector<PieceInfo*> SortedPieces;
 			SortedPieces.reserve(Library->mPieces.size());
+			const lcModel* ActiveModel = gMainWindow->GetActiveModel();
 
 			for (const auto& PartIt : Library->mPieces)
-				SortedPieces.push_back(PartIt.second);
+			{
+				PieceInfo* Info = PartIt.second;
+
+				if (!Info->IsModel() || !Info->GetModel()->IncludesModel(ActiveModel))
+					SortedPieces.push_back(PartIt.second);
+			}
 
 			auto PieceCompare = [](PieceInfo* Info1, PieceInfo* Info2)
 			{
@@ -788,7 +794,10 @@ void lcQPropertiesTree::slotColorButtonClicked()
 	connect(Popup, SIGNAL(selected(int)), SLOT(slotSetValue(int)));
 	Popup->setMinimumSize(qMax(300, width()), qMax(200, static_cast<int>(width() * 2 / 3)));
 
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+	QScreen* Screen = Button->screen();
+	const QRect ScreenRect = Screen ? Screen->geometry() : QRect();
+#elif (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
 	QScreen* Screen = QGuiApplication::screenAt(Button->mapToGlobal(Button->rect().bottomLeft()));
 	const QRect ScreenRect = Screen ? Screen->geometry() : QApplication::desktop()->geometry();
 #else
