@@ -6,6 +6,31 @@ namespace Ui {
 class lcRenderDialog;
 }
 
+class lcRenderPreviewWidget : public QWidget
+{
+	Q_OBJECT
+
+public:
+	lcRenderPreviewWidget(QWidget* Parent)
+		: QWidget(Parent)
+	{
+	}
+
+	void SetImage(QImage Image)
+	{
+		mImage = Image;
+		mScaledImage = QImage();
+		update();
+	}
+
+protected:
+	void resizeEvent(QResizeEvent* Event) override;
+	void paintEvent(QPaintEvent* PaintEvent) override;
+
+	QImage mImage;
+	QImage mScaledImage;
+};
+
 class lcRenderDialog : public QDialog
 {
 	Q_OBJECT
@@ -15,7 +40,7 @@ public:
 	~lcRenderDialog();
 
 public slots:
-	void reject();
+	void reject() override;
 	void on_RenderButton_clicked();
 	void on_OutputBrowseButton_clicked();
 	void Update();
